@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0601';
+our $VERSION = '0.0602';
 
 use strict;
 use warnings;
@@ -149,20 +149,51 @@ sub fingering {
         my $diff = $target - _lowest_c($pitches);
 
         my ($str, $pos) = split /-/, $fingering;
-        push @fingering, $str . '-' . ($pos + $diff);
+        my $p = $pos + $diff;
+        if ($p == 0 && $str !~ /0/) {
+            $str = _decrement_fingering($str);
+            $p++;
+        }
+        elsif ($p != 0 && $str =~ /0/) {
+            $str = _increment_fingering($str);
+        }
+        push @fingering, $str . '-' . $p;
     }
     else {
         for (zip $self->chords->{ 'C' . $chord_name }{notes}, $self->chords->{ 'C' . $chord_name }{fingering}) {
             my ($pitches, $fingering) = @$_;
             my $diff = $target - _lowest_c($pitches);
             my ($str, $pos) = split /-/, $fingering;
-            push @fingering, $str . '-' . ($pos + $diff);
+            my $p = $pos + $diff;
+            if ($p == 0) {
+                $str = _decrement_fingering($str);
+                $p++;
+            }
+            push @fingering, $str . '-' . $p;
         }
     }
 
     return \@fingering;
 }
 
+sub _increment_fingering {
+    my ($fingering) = @_;
+    my $incremented = '';
+    for my $char (split //, $fingering) {
+        $incremented .= $char =~ /\d/ ? $char + 1 : $char;
+    }
+    return $incremented;
+}
+
+sub _decrement_fingering {
+    my ($fingering) = @_;
+    my $decremented = '';
+    for my $char (split //, $fingering) {
+        $decremented .= $char =~ /\d/ ? $char - 1 : $char;
+    }
+    return $decremented;
+}
+
 1;
 
 __END__
@@ -177,7 +208,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0601
+version 0.0602
 
 =head1 SYNOPSIS
 
